@@ -8,7 +8,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 
-from ..parsers.optimized_parameters import ParametersArray
+from atmoswing_toolbox.parsers.optimized_parameters import ParametersArray
 
 
 class GAsVariablesPlot:
